@@ -80,7 +80,7 @@ class EntityMapper():
         return entity
 
 
-    def map_entities(self, text, doc_path=''):
+    def map_entities(self, text, doc_path='', entity_types=None):
         '''
         Maps entities in given text.
 
@@ -94,6 +94,9 @@ class EntityMapper():
         filtered_mappings -- A sorted (descending by value lenght) dict that has redundant matches removed.
         For example: {'addr': [{'span': (57, 69), 'doc_path': '', 'value': u'Street 2'}, {'span': (41, 51), 'doc_path': '', 'value': u'Street 1'}]}
         '''
+        if not entity_types:
+            entity_types = list(self.entities.keys())
+
         mappings = []
 
         text = self._normalize_string(text)
@@ -105,9 +108,10 @@ class EntityMapper():
                 # Checks if ngram is in the entity map. If so, define its type and add it to the mappings
                 if ngram in self.entity_map:
                     entity_type = self.entity_map[ngram]
-                    mapping = {'entity_type': entity_type, 'entity': ngram}
-                    if mapping not in mappings:
-                        mappings.append(mapping)
+                    if entity_type in entity_types:
+                        mapping = {'entity_type': entity_type, 'entity': ngram}
+                        if mapping not in mappings:
+                            mappings.append(mapping)
         mappings_dict = {}
         for mapping in mappings:
             if mapping['entity_type'] not in mappings_dict:
